{
  "type": "record",
  "Aspect": {
    "name": "dataHubMetricCubeKey",
    "keyForEntity": "dataHubMetricCube",
    "entityCategory": "internal",
    "entityAspects": [
      "dataHubMetricCubeDefinition",
      "dataHubMetricCubeEvent"
    ]
  },
  "name": "DataHubMetricCubeKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "fields": [
    {
      "type": "string",
      "name": "id",
      "doc": "Unique id for the cube type."
    }
  ],
  "doc": "Key for a DataHub Metric Cube, e.g. an internal metric."
}